angular.module('starter.services', [])

//----------------------------------------------------------------------
// App配置文件
//----------------------------------------------------------------------
.factory('AppConfig', function($log, $http, $rootScope) {
  var promise = null;
  if (!$rootScope.APP_CONFIG) {
    promise = $http.get('js/app_config.json');
    promise.success(function(data, status) {
      $rootScope.APP_CONFIG = data;
    });
  }
  return {
    initConfig: function() {
      return promise;
    },
    getConfig: function() {
      return $rootScope.APP_CONFIG;
    }
  };
})

//----------------------------------------------------------------------
// 常量
//----------------------------------------------------------------------
.factory('Constants', function() {
  return {
    pageItem: 10,
    drift_rate: '0.5',
    pointcode: '20',
    logincode: '3',
    rewardRuleString: "红包是好班为入驻好班的机构提供的一项增值服务，分为等额现金红包、随机现金红包和优惠券红包三类，由入驻好班的机构批量发送，好班运营者也会根据运营需要使用红包功能。\n发红包人可以设置红包的面额（随机面额红包面额最大值）、数量、开始时间、（抵用券红包到期时间）、发布范围及使用说明等，并向好班账户与支付红包总金额。机构所发红包必须经过好班审核才能正式发布。\n处于红包设定区域范围内的用户可以参与抢红包活动，每批次红包对于用户只有一次机会，用户获得的现金红包直接进入用户在好班的钱包余额，优惠券红包则依据红包设置只能在指定机构中、指定时间内用于抵扣交易款。\n好班将根据需要开发不同版本的app产品入驻各类应用发布市场（包括但不限于苹果应用程序商店、百度手机助手），好班的所有红包活动均与进驻的应用市场无关。",
    downloadURL: function() {
      var url;
      if (ionic.Platform.isIOS()) {
        url = "http://www.haoban173.com";
      } else {
        url = "http://www.haoban173.com";
      }
      return url;
    }
  };
})

//----------------------------------------------------------------------
// 网络通讯
//----------------------------------------------------------------------
.factory('Network', function($rootScope, $timeout, AppConfig, Common, $http, $ionicPopup, $ionicBackdrop, $cordovaToast, $ionicLoading) {
  return {
    loading: function(pare, url, callBack) {
      // 通讯参数
      var json = pare;
      // 通讯路径
      var base_api = AppConfig.getConfig().BASE_API;
      var apiUrl = base_api + url;
      // 组织通讯头
      var header = Common.commonHeaders(apiUrl, json);

      var request = $http({
        method: 'post',
        url: apiUrl,
        data: 'json=' + JSON.stringify(json).replace(/%/g,"%25").replace(/\&/g,"%26").replace(/\+/g,"%2B"),
        headers: header,
        timeout: 30000
      }).success(function(data, status, headers, config) { // 通讯成功
        $ionicLoading.hide();
        if (data.status.succeed == 1) { // 获取数据成功
          callBack(data);
        } else {
          $rootScope.reportInfo = null;
          $cordovaToast.showShortCenter(data.status.error_desc);
        }
      }).error(function(data, status, headers, config) { // 通讯失败
        $rootScope.reportInfo = null;
        $ionicLoading.hide();
        $cordovaToast.showShortCenter("网络异常，请检查网络");
        return false;
      });
    }
  };
})

//----------------------------------------------------------------------
// 属性初始化
//----------------------------------------------------------------------
.factory("InitConfig", function($q, AppConfig) {
  return {
    initialize: function() {
      var deferred = $q.defer();
      var promises = [];
      promises.push(AppConfig.initConfig());
      $q.all(promises).then(function(response) {
        deferred.resolve(response);
      });
      return deferred.promise;
    }
  };
})

//----------------------------------------------------------------------
// 网络通讯相关
//----------------------------------------------------------------------
.factory('Common', function($ionicPopup, $timeout, $state, AppConfig, $cordovaGeolocation, $cordovaToast) {
  return {
    showPopupMessage: function(message) {
      var myPopup = $ionicPopup.show({
        template: message,
      });
      $timeout(function() {
        // 1秒钟自动关闭
        myPopup.close();
      }, 1000);
    },

    commonHeaders: function(url, data) {
      var authKey = AppConfig.getConfig().AUTH_KEY;
      var base_api = AppConfig.getConfig().BASE_API;

      url = url.substring(base_api.length);

      var customHeaders = {};

      if (url.charAt(url.length - 1) == '/') {
        url = url.substring(0, (url.length - 1));
      }

      var salt = CryptoJS.lib.WordArray.random(128 / 8);
      var key128Bits = CryptoJS.PBKDF2(new Date() + 1, salt, {
        keySize: 128 / 32
      });
      var key = key128Bits + authKey;
      if (data) {
        data = JSON.stringify(data) + url;
      } else {
        data = url;
      }

      var signKey = CryptoJS.HmacSHA256(data, key);
      customHeaders['X-Sign-Id'] = signKey.toString() + key128Bits;

      return customHeaders;
    },
    getGPS: function(callBack){
      latitude = null;
      longitude = null;
      if (ionic.Platform.isIOS()) {
        var posOption = {enableHighAccuracy: true};
        //  navigator.geolocation.
        $cordovaGeolocation.getCurrentPosition(posOption).then(function(position) {
          latitude = position.coords.latitude + '';
          longitude = position.coords.longitude + '';
          callBack();
        }, function(err) {
          latitude = null;
          longitude = null;
          callBack();
          switch(err.code) {  
            case err.TIMEOUT :  
              $cordovaToast.showShortCenter('连接超时，请重试');
              break; 
            case err.POSITION_UNAVAILABLE :  
              $cordovaToast.showShortCenter('无法获取到地理位置信息');
              break;  
            } 
        });
      } else {
        baidu_location.getCurrentPosition(function(json) {
          console.log(json);
          latitude = json.latitude + '';
          longitude = json.lontitude + '';
          callBack();
        }, function(err) {
          latitude = null;
          longitude = null;
          callBack();
          console.log(err);
        });
      }
    }
  };
})

//----------------------------------------------------------------------
// 分享
//----------------------------------------------------------------------
.factory("Share", function(Network, $cordovaToast, $ionicPopup, $ionicActionSheet, AppConfig) {

  var QQshare = function(img, name, des, url, callback) {
    YCQQ.checkClientInstalled(function() {
      var args = {};
      args.url = url;
      args.title = name;
      args.description = des;
      var imgs = [img];
      args.imageUrl = imgs;
      YCQQ.shareToQzone(function() {
        callback('1');
      }, function(failReason) {
        if (failReason == "QZone share is cancelled") {
          $cordovaToast.showShortCenter('取消分享');
        } else {
          $cordovaToast.showShortCenter('分享失败');
        }
        callback('2');
      }, args);
    }, function() {
      console.log('client is not installed');
      $cordovaToast.showShortBottom('没有安装客户端，分享失败');
      callback('2');
    });
  };
  var Wecharshare = function(img, name, des, url, callback) {
    Wechat.isInstalled(function(installed) {
      Wechat.share({
        message: {
          title: name,
          description: des,
          thumb: img,
          mediaTagName: "TEST-TAG-001",
          messageExt: des,
          messageAction: "<action>dotalist</action>",
          media: {
            type: Wechat.Type.LINK,
            webpageUrl: url
          }
        },
        scene: Wechat.Scene.SESSION // share to Timeline
      }, function() {
        callback('1');
      }, function(reason) {
        if (reason == "ERR_USER_CANCEL") {
          $cordovaToast.showShortCenter('取消分享');
        } else {
          $cordovaToast.showShortCenter('分享失败');
        }
        callback('2');
      });
    }, function(reason) {
      console.log('client is not installed');
      $cordovaToast.showShortBottom('没有安装客户端，分享失败');
      callback('2');
    });
  };
  var Weiboshare = function(img, name, des, url, callback) {
    var args = {};
    args.url = url;
    args.title = name;
    args.description = des;
    args.imageUrl = img;
    args.defaultText = des;

    YCWeibo.shareToWeibo(function() {
      callback('1');
    }, function(failReason) {
      if (failReason == "cancel by user") {
        $cordovaToast.showShortCenter('取消分享');
      } else {
        $cordovaToast.showShortCenter('分享失败');
      }

      callback('2');
    }, args);
  };
  var weshare = function(img, name, des, url, callback) {
    Wechat.isInstalled(function(installed) {
      Wechat.share({
        message: {
          title: name,
          description: des,
          thumb: img,
          mediaTagName: "TEST-TAG-001",
          messageExt: name,
          messageAction: "<action>dotalist</action>",
          media: {
            type: Wechat.Type.LINK,
            webpageUrl: url
          }
        },
        scene: Wechat.Scene.TIMELINE // share to Timeline
      }, function() {
        callback('1');
      }, function(reason) {
        if (reason == "ERR_USER_CANCEL") {
          $cordovaToast.showShortCenter('取消分享');
        } else {
          $cordovaToast.showShortCenter('分享失败');
        }
        callback('2');
      });
    }, function(reason) {
      console.log('client is not installed');
      $cordovaToast.showShortBottom('没有安装客户端，分享失败');
      callback('2');
    });
  };
  return {
    ActionSheetShare: function(img, name, des, shareId, type, agentName, shareBack) {
      var destructiveRemindText = '';
      var imgUrl = AppConfig.getConfig().BASE_API + img;
      var newday = new Date().format('yyyy-MM-dd');
      var url = AppConfig.getConfig().BASE_API + '/api/mst_share/';
      if (!des) {
        des = '';
      };
      switch (type) {
        case 1:
            url = url + 'courseShareUrl?ids=' + shareId + '&date=' + newday;
            destructiveRemindText = '好班（含app应用及web后台网站，以下简称好班）的所有权和运营权归北京清大世纪教育投资顾问有限公司（下称本公司）所有。';
          break;
        case 2:
            url = url + 'agentShareUrl?ids=' + shareId + '&date=' + newday;
            destructiveRemindText = '好班（含app应用及web后台网站，以下简称好班）的所有权和运营权归北京清大世纪教育投资顾问有限公司（下称本公司）所有。';
          break;
        case 3:
            url = url + 'evalShareUrl?ids=' + shareId + '&date=' + newday;
            destructiveRemindText = '好班（含app应用及web后台网站，以下简称好班）的所有权和运营权归北京清大世纪教育投资顾问有限公司（下称本公司）所有。';
          break;
        case 4:
            name = '我抢到了一个红包';
            url = url + 'rewardShareUrl?money=' + shareId + '&name=' + encodeURI(encodeURI(agentName)) + '&date=' + newday;
            destructiveRemindText = '好班（含app应用及web后台网站，以下简称好班）的所有权和运营权归北京清大世纪教育投资顾问有限公司（下称本公司）所有。';
          break;
        case 5:
            name = '我预约了' + name;
            url = url + 'breakeShareUrl?ids=' + shareId + '&date=' + newday;
            destructiveRemindText = '课程预约成功，将预约的课程分享可获得一次抢红包机会！';
          break;
        default:
          break;
      }
      var hideSheet = $ionicActionSheet.show({
        buttons: [
            {text: '<div class="top-icon calm-bg"><i class="custom-share-icon"><img src="img/qzone.svg"></i></div><div class="bottom-text">QQ空间</div>'},
            {text: '<div class="top-icon balanced-bg"><i class="fa fa-weixin white"></i></div><div class="bottom-text">微信</div>'},
            {text: '<div class="top-icon energized-bg"><i class="ion-aperture white"></i></div><div class="bottom-text">朋友圈</div>'},
            {text: '<div class="top-icon assertive-bg"><i class="fa fa-weibo white"></i></div><div class="bottom-text">新浪微博</div>'}
        ],
        destructiveText: destructiveRemindText,//destructiveText: '删除的(可取消不写)',
        titleText: '分享至',
        cancelText: '取消',
        buttonClicked: function(index) {
          switch (index) {
            case 0:
              QQshare(imgUrl, name, des, url, function(res) {
                shareBack(res);
              });
              break;
            case 1:
              Wecharshare(imgUrl, name, des, url, function(res) {
                shareBack(res);
              });
              break;
            case 2:
              weshare(imgUrl, name, des, url, function(res) {
                shareBack(res);
              });
              break;
            case 3:
              Weiboshare(imgUrl, name, des, url, function(res) {
                shareBack(res);
              });
              break;
            default:
              break;
          }
          return true;
        }
      });
    },
    PopupShare: function(img, name, des, shareId, type, index, agentName, shareBack) {
      var imgUrl = AppConfig.getConfig().BASE_API + img;
      var newday = new Date().format('yyyy-MM-dd');
      var url = AppConfig.getConfig().BASE_API + '/api/mst_share/';
       url = url + 'evalShareUrl?' + shareId + '&date=' + newday;
      if (!des) {
        des = '';
      };
      switch (index) {
        case 0:
          QQshare(imgUrl, name, des, url, function(res) {
            shareBack(res);
          });
          break;
        case 1:
          Wecharshare(imgUrl, name, des, url, function(res) {
            shareBack(res);
          });
          break;
        case 2:
          weshare(imgUrl, name, des, url, function(res) {
            shareBack(res);
          });
          break;
        case 3:
          Weiboshare(imgUrl, name, des, url, function(res) {
            shareBack(res);
          });
          break;
        default:
          break;
      }
    }
  };
})
  .factory("InmobiService", function ($http, AppConfig, Common) {
    return {
      activate: function () {
        var action = "shopper_ios";
        var inmobiServiceUrl = AppConfig.getConfig().INMOBI_SERVICE_URL;
        var header = Common.commonHeaders(inmobiServiceUrl);
        window.plugins.AppleAdvertising.getIDFA(function (idfa) {
          $http({
            method: 'post',
            url: inmobiServiceUrl,
            data: "action=" + action + "&idfa=" + idfa,
            headers: header,
            timeout: 15000
          });
        }, function () {
          console.log("err");
          $http({
            method: 'post',
            url: inmobiServiceUrl,
            data: "action=" + action,
            headers: header,
            timeout: 15000
          });
        });

        return null;
      }
    };
  })
  .factory("ChanceService", function ($http, AppConfig, Common) {
      return{
        activate:function(){
          var action = "shopper_ios";
          var chanceServiceUrl = AppConfig.getConfig().CHANCE_SERVICE_URL;
          var header = Common.commonHeaders(chanceServiceUrl);
          window.plugins.AppleAdvertising.getIDFA(function(idfa){
            $http({
              method: 'post',
              url: chanceServiceUrl,
              data: "action=" + action + "&idfa=" + idfa,
              headers: header,
              timeout: 15000
            });
          },function(){
            console.log("err");
            $http({
              method: 'post',
              url: chanceServiceUrl,
              data: "action=" + action,
              headers: header,
              timeout: 15000
            });
          });

          return null;
        }
      };
  });